@@ -15,14 +15,16 @@ import aws_cdk.aws_ecr._jsii
 import aws_cdk.aws_ecs._jsii
 import aws_cdk.aws_elasticloadbalancingv2._jsii
 import aws_cdk.aws_iam._jsii
+import aws_cdk.aws_lambda._jsii
 import aws_cdk.core._jsii
+import aws_cdk.custom_resources._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@cloudcomponents/cdk-blue-green-container-deployment",
-    "1.41.0",
+    "1.45.0",
     __name__[0:-6],
-    "cdk-blue-green-container-deployment@1.41.0.jsii.tgz",
+    "cdk-blue-green-container-deployment@1.45.0.jsii.tgz",
 )
 
 __all__ = [
